/**
  ******************************************************************************
  * @file    sh32f9xx_sc0_rcc.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    2021-05-21  
  * @brief   This file provides reset and clock module's APIs
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2021 Sinowealth</center></h2>
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH32F9XX_SC0_RCC_H
#define __SH32F9XX_SC0_RCC_H


/* Includes ------------------------------------------------------------------*/
#include "sh32f9xx_sc0_libcfg.h"

/** @defgroup RCC_Group_Constant  Public Constants
  * @{
  */ 
/*!< CLOCK SOURCE CONSTANT */
typedef enum {
    RCC_SYS_SRC_LSI  = 0,
    RCC_SYS_SRC_HSI  = 1,
    RCC_SYS_SRC_PLL  = 2,
    RCC_SYS_SRC_HSE  = 3,
}RCC_SysSource_Type;

typedef enum {
    PLL_SRC_HSI   = 0,
    PLL_SRC_HSE   = 1,
}RCC_PLL_SRC_Type;

/*! @struct  RCC_Clocks_TypeDef
  *  RCC structure of clock frequency datas, used to get current system's clock frequency
  */    
typedef struct
{
    uint32_t sysFreq;  /*!<  System clock frequency, unit is Hz */
    uint32_t hclkFreq;    /*!< AHB bus clock frequency, unit is Hz */
    uint32_t pclk0Freq;   /*!< APB0 bus clock frequency, unit is Hz */
    uint32_t pclk1Freq;   /*!< APB1 bus clock frequency, unit is Hz */
}RCC_Clocks_TypeDef;


/*!  RCC AHB Modules */
typedef enum{
    RCC_AHB_GPIO       = RCC_AHBENR_GPIOEN_Msk,
    RCC_AHB_SYSCFG     = RCC_AHBENR_SYSCFGEN_Msk,
    RCC_AHB_DMA        = RCC_AHBENR_DMAEN_Msk,
    RCC_AHB_CRC        = RCC_AHBENR_CRCEN_Msk,
    RCC_AHB_RAMBIST    = RCC_AHBENR_RAMBISTEN_Msk,
    RCC_AHB_ADC0       = RCC_AHBENR_ADC0EN_Msk,
    RCC_AHB_ADC1       = RCC_AHBENR_ADC1EN_Msk,   
    RCC_AHB_GPT        = RCC_AHBENR_GPTEN_Msk,
    RCC_AHB_GPT0       = RCC_AHBENR_GPT0EN_Msk,
    RCC_AHB_GPT1       = RCC_AHBENR_GPT1EN_Msk,
    RCC_AHB_GPT2       = RCC_AHBENR_GPT2EN_Msk,
    RCC_AHB_GPT3       = RCC_AHBENR_GPT3EN_Msk,
}RCC_AHB_Type;

/*! All AHB  Modules */
#define RCC_AHB_ALL    (0x03E6F4)

/*! check AHB Module source */
#define IS_AHB_MODULES(m)   ((((m ) & RCC_AHB_ALL) != 0) && (((m) & (~RCC_AHB_ALL)) == 0))

/*!  RCC APB0 Modules */
typedef enum{
    RCC_APB0_TIM5   = APB0_CFG_APB0ENR_TIM5EN_Msk,
    RCC_APB0_TIM6   = APB0_CFG_APB0ENR_TIM6EN_Msk,
    RCC_APB0_TIM7   = APB0_CFG_APB0ENR_TIM7EN_Msk,
    RCC_APB0_TIM8   = APB0_CFG_APB0ENR_TIM8EN_Msk,
    RCC_APB0_AMOC   = APB0_CFG_APB0ENR_AMOCEN_Msk,
    RCC_APB0_UART0  = APB0_CFG_APB0ENR_UART0EN_Msk,
    RCC_APB0_UART1  = APB0_CFG_APB0ENR_UART1EN_Msk,
    RCC_APB0_UART2  = APB0_CFG_APB0ENR_UART2EN_Msk,
    RCC_APB0_UART3  = APB0_CFG_APB0ENR_UART3EN_Msk,
    RCC_APB0_UART4  = APB0_CFG_APB0ENR_UART4EN_Msk,
    RCC_APB0_UART5  = APB0_CFG_APB0ENR_UART5EN_Msk,
    RCC_APB0_SPI0   = APB0_CFG_APB0ENR_SPI0EN_Msk,
    RCC_APB0_SPI1   = APB0_CFG_APB0ENR_SPI1EN_Msk,
    RCC_APB0_TWI0   = APB0_CFG_APB0ENR_TWI0EN_Msk,
    RCC_APB0_TWI1   = APB0_CFG_APB0ENR_TWI1EN_Msk,
    RCC_APB0_TK     = APB0_CFG_APB0ENR_TKEN_Msk,
    RCC_APB0_WWDT   = APB0_CFG_APB0ENR_WWDTEN_Msk,
 
}RCC_APB0_Type;

/*! All APB0  Modules */
#define RCC_APB0_ALL    (0x03FFCF)

/*! check APB0 clock source */
#define IS_APB0_MODULES(m) ((((m ) & RCC_APB0_ALL) != 0) && (((m) & (~RCC_APB0_ALL)) == 0))

/*!  RCC APB1 Modules */
typedef enum{
    RCC_APB1_EXTI   = APB1_CFG_APB1ENR_EXTIEN_Msk,
}RCC_APB1_Type;

/*! All APB1  Modules */
#define RCC_APB1_ALL    (0x0001)

/*! check APB1 clock source */
#define IS_APB1_MODULES(m) ((((m ) & RCC_APB1_ALL) != 0) && (((m) & (~RCC_APB1_ALL)) == 0))

/*!  RCC RSTSTR Modules */
typedef enum{
    RCC_RST_PIN         = RCC_RSTSTR_PINRSTF_Msk,  
    RCC_RST_LVR         = RCC_RSTSTR_LVRSTF_Msk,
    RCC_RST_POWERON     = RCC_RSTSTR_PORSTF_Msk, 
    RCC_RST_SOFTWARE    = RCC_RSTSTR_SWRSTF_Msk,
    RCC_RST_IWDT        = RCC_RSTSTR_IWDTRSTF_Msk,
    RCC_RST_WWDT        = RCC_RSTSTR_WWDTRSTF_Msk, 
    RCC_RST_VCCLVR      = RCC_RSTSTR_LVRSTF2_Msk, 
}RCC_RESET_Type;

/*! All RST  Modules */
#define RCC_RST_ALL    (0x007F)

/*! check RST clock source */
#define IS_RST_MODULES(m) ((((m ) & RCC_RST_ALL) != 0) && (((m) & (~RCC_RST_ALL)) == 0))

typedef enum
{
    RCC_CIENR_HSERDYIE = RCC_CIENR_HSERDYIE_Msk,
    RCC_CIENR_PLLRDYIE = RCC_CIENR_PLLRDYIE_Msk,
} RCC_CIENR_Type;
#define RCC_CIENR_ALL               (0x0018)
#define IS_CIENR_REGISTER(m)        ((((m)&RCC_CIENR_ALL) != 0) && (((m) & (~RCC_CIENR_ALL)) == 0))
typedef enum
{
    RCC_CSM_HSE_RF = RCC_CISTR_HSERDYIF_Msk,
    RCC_CSM_PLL_RF = RCC_CISTR_PLLRDYIF_Msk,
    RCC_CSM_HSE_IF = RCC_CISTR_CSMHSEF_Msk,
    RCC_CSM_PLL_IF = RCC_CISTR_CSMPLLF_Msk,
} RCC_CSMF_Type;
#define RCC_CSMF_ALL                (0x00D8)
#define IS_CSM_FLAG(m)              ((((m)&RCC_CSMF_ALL) != 0) && (((m) & (~RCC_CSMF_ALL)) == 0))
typedef enum
{
    RCC_CSM_CICCLR_CSMC    = RCC_CICLR_CSMC_Msk,
    RCC_CSM_CICCLR_PLLRDYC = RCC_CICLR_PLLRDYC_Msk,
    RCC_CSM_CICCLR_HSERDYC = RCC_CICLR_HSERDYC_Msk,
} RCC_CICCLR_Type;
#define RCC_CICCLR_ALL              (0x0098)
#define IS_CICCLR_FLAG(m)           ((((m)&RCC_CICCLR_ALL) != 0) && (((m) & (~RCC_CICCLR_ALL)) == 0))

/*!  RCC CSM select frequency */
typedef enum{
    RCC_CSMSEL_4M         = 0X00,
    RCC_CSMSEL_6M         = 0X01,
    RCC_CSMSEL_8M         = 0X02, 
    RCC_CSMSEL_12M        = 0X03,
}RCC_CSMSEL_Type; 
/*!  check CRC mode selection */
#define IS_RCC_CSM_SEL(mode)   (((mode) == RCC_CSMSEL_4M )     \
                               || ((mode) == RCC_CSMSEL_6M )   \
                               || ((mode) == RCC_CSMSEL_8M)    \
                               || ((mode) == RCC_CSMSEL_12M ))

/** 
  *@brief  Unlock the RCC module's regsiter. RCC registers can be modified.
  */
#define RCC_REGS_UNLOCK()        RCC->RCCLOCK=0x33CC

/** 
  *@brief  Lock the RCC module's regsiter. RCC registers cannot be modified.
  */
#define RCC_REGS_LOCK()          RCC->RCCLOCK=0

/** 
  *@brief  Unlock the APB0_CFG module's regsiter. APB0_CFG registers can be modified.
  */
#define APB0_CFG_REGS_UNLOCK()   APB0_CFG->RCCLOCK=0x33CC

/** 
  *@brief  Lock the APB0_CFG module's regsiter. APB0_CFG registers cannot be modified.
  */
#define APB0_CFG_REGS_LOCK()     APB0_CFG->RCCLOCK=0

/** 
  *@brief  Unlock the APB1_CFG module's regsiter. APB1_CFG registers can be modified.
  */
#define APB1_CFG_REGS_UNLOCK()   APB1_CFG->RCCLOCK=0x33CC

/** 
  *@brief  Lock the APB1_CFG module's regsiter. APB1_CFG registers cannot be modified.
  */
#define APB1_CFG_REGS_LOCK()     APB1_CFG->RCCLOCK=0

/* get current clock requency*/
void RCC_GetClocksFreq(RCC_Clocks_TypeDef *Clocks);  

/* configure AHB modules' clock gate */ 
void RCC_AHBPeriphClockOnOff(RCC_AHB_Type AHBModules, CmdState OnOffState);

/* configure APB1 modules' clock gate */ 
void RCC_APB1PeriphClockOnOff(RCC_APB1_Type APB1Modules, CmdState OnOffState);

/* configure APB0 modules' clock gate */ 
void RCC_APB0PeriphClockOnOff(RCC_APB0_Type APB0Modules, CmdState OnOffState);

/* reset AHB modules*/ 
void RCC_AHBPeriphReset(uint32_t AHBModules);

/* reset APB0 modules*/ 
void RCC_APB0PeriphReset(uint32_t APB0Modules);

/* reset APB1 modules*/ 
void RCC_APB1PeriphReset(uint32_t APB1Modules);

/* Get RCC reset flag*/
FlagStatus RCC_GetResetFlag(RCC_RESET_Type ResetFlag);

/* clear RCC reset flags*/
void RCC_ClearResetFlag(RCC_RESET_Type ResetFlags);

void RCC_CSMModuleOnOff(CmdState OnOffState);

FlagStatus RCC_GetCsmFStatus(RCC_CSMF_Type CSMFlag);

void RCC_ClearITPendingBit(RCC_CICCLR_Type CLK_INTFLG_CLR);

void RCC_INTConfig(RCC_CIENR_Type RDYINTIE, FunctionalState NewState);
/**
  * @}
  */ 
#endif
/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
