/**
  ******************************************************************************
  * @file    sh32f9xx_sc0_syscfg.h
  * @author  sinowealth
  * @version V1.1.0
  * @date    2021-05-21  
  * @brief   This file contains all the functions prototypes for the SYSCFG firmware
  *          library.
  ******************************************************************************
  * @attention
  *
  * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S 
  * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS. 
  * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE TIME. AS A RESULT, SINOWEALTH 
  * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES 
  * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
  * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN 
  * CONNECTION WITH THEIR PRODUCTS.
  *
  * <h2><center>&copy; COPYRIGHT 2021 Sinowealth</center></h2>
  *
  *
  ******************************************************************************
  */

/* Define to prevent recursive inclusion -------------------------------------*/
#ifndef __SH32F9XX_SC0_SYSCFG_H
#define __SH32F9XX_SC0_SYSCFG_H

#ifdef __cplusplus
 extern "C" {
#endif

/* Includes ------------------------------------------------------------------*/
#include "sh32f9xx_sc0_libcfg.h"


typedef enum
{
    SYSCFG_VLVR_Level_4V1 = 0x00,
    SYSCFG_VLVR_Level_3V7 = 0x01,
    SYSCFG_VLVR_Level_2V8 = 0x02,
    SYSCFG_VLVR_Level_2V1 = 0x03,
    SYSCFG_VLVR_Level_1V9 = 0x04,
}SYSCFG_VLVR_LEVEL_Type;    

#define IS_SYSCFG_VLVR_LEVEL(LEVEL)  ((LEVEL == SYSCFG_VLVR_Level_4V1)   \
                                     || (LEVEL == SYSCFG_VLVR_Level_3V7) \
                                     || (LEVEL == SYSCFG_VLVR_Level_2V8) \
                                     || (LEVEL == SYSCFG_VLVR_Level_2V1) \
                                     || (LEVEL == SYSCFG_VLVR_Level_1V9))
                                   

#define SYSCFG_SLEEPEntry_WFI          (uint8_t)0x00
#define SYSCFG_SLEEPEntry_WFE          (uint8_t)0x01

#define IS_SYSCFG_SLEEP_ENTRY(ENTRY)   ((ENTRY == SYSCFG_SLEEPEntry_WFI) \
                                       || (ENTRY == SYSCFG_SLEEPEntry_WFE))




#define SYSCFG_STOPEntry_WFI          (uint8_t)0x00
#define SYSCFG_STOPEntry_WFE          (uint8_t)0x01

#define IS_SYSCFG_SLOP_ENTRY(ENTRY)   ((ENTRY == SYSCFG_STOPEntry_WFI) \
                                      || (ENTRY == SYSCFG_STOPEntry_WFE))

typedef enum
{
    SYSCFG_SWJ_All_Function = 0x00,
    SYSCFG_SWD_CLOSE_PinRemap = 0x01,
}SYSCFG_SWJCFG_Type;

#define IS_SYSCFG_SWJ_PIN_MODE(MODE)   ((MODE == SYSCFG_SWJ_All_Function) \
                                       || (MODE == SYSCFG_SWD_CLOSE_PinRemap))




typedef enum
{
    SYSCFG_OSC_GPIO     = 0x00,
    SYSCFG_OSC_Crystal  = 0x01,
    SYSCFG_OSC_ExtClock = 0x02
}SYSCFG_OSCPin_Type;

#define IS_SYSCFG_OSC_PIN_MODE(MODE)   ((MODE == SYSCFG_OSC_GPIO)      \
                                       || (MODE == SYSCFG_OSC_Crystal) \
                                       || (MODE == SYSCFG_OSC_ExtClock))



#define SYSCFG_NMI_TRIGGER_CSM       (uint16_t)0x0100
#define SYSCFG_NMI_TRIGGER_EXTI0     (uint16_t)0x0040

#define IS_SYSCFG_NMI_TRIGGER_SOURCE(SOURCE)  (((SOURCE & (uint16_t)0xFEBF) == 0x00) \
                                              && (SOURCE != 0x00))





#define CRAM_Sector_0      (uint8_t)0x01
#define CRAM_Sector_1      (uint8_t)0x02
#define CRAM_Sector_2      (uint8_t)0x04
#define CRAM_Sector_3      (uint8_t)0x08
#define CRAM_Sector_4      (uint8_t)0x10
#define CRAM_Sector_5      (uint8_t)0x20
#define CRAM_Sector_6      (uint8_t)0x40
#define CRAM_Sector_7      (uint8_t)0x80

#define IS_SYSCFG_CRAM_SECTOR(LOCK_SECTOR)   (LOCK_SECTOR != 0x00)


                                                  
#define DBG_Periph_GPT     (uint16_t)0x0010
#define DBG_Periph_DMA     (uint16_t)0x0020
#define DBG_Periph_IWDT    (uint16_t)0x0040
#define DBG_Periph_WWDT    (uint16_t)0x0080
#define DBG_Periph_TK      (uint16_t)0x0100
#define DBG_Periph_TIM     (uint16_t)0x0200

#define DBG_Periph_UART    (uint16_t)0x0800
#define DBG_Periph_SPI     (uint16_t)0x1000
#define DBG_Periph_TWI     (uint16_t)0x2000

#define IS_DBG_PERIPH(PERIPH)  (((PERIPH & (uint16_t)0xC40F) == 0x00) && (PERIPH != 0x00))
                                               

#define DBG_LOWPOWER_SLEEP          (uint16_t)0x0001
#define DBG_LOWPOWER_STOP           (uint16_t)0x0002      
#define IS_DBG_LOWPOWER_MODE(MODE)  (((MODE & (uint16_t)0xFFFC) == 0x00) && (MODE != 0x00))                                       

/* Exported functions --------------------------------------------------------*/ 
extern void SYSCFG_VLVRInit(SYSCFG_VLVR_LEVEL_Type SYSCFG_VLVR_Level);
extern void SYSCFG_VLVRConfig(FunctionalState NewState);
extern void SYSCFG_EnterSLEEPMode(uint8_t SYSCFG_SLEEPEntry);
extern void SYSCFG_EnterSTOPMode(uint8_t SYSCFG_STOPEntry);
extern void SYSCFG_NMIInterruptTriggerConfig(uint16_t TriggerSource, FunctionalState NewState);
extern void SYSCFG_SWJPinConfig(SYSCFG_SWJCFG_Type SWJPin_Mode);
extern void SYSCFG_OSCPinConfig(SYSCFG_OSCPin_Type OSCPin_Mode);
extern void SYSCFG_CRAMLockConfig(uint8_t SectorNum, FunctionalState NewState);
extern void SYSCFG_DBGPeriphConfig(uint16_t DBG_Periph, FunctionalState NewState);
extern void SYSCFG_DBGLowPowerConfig(uint16_t LowPowerMode, FunctionalState NewState);

#ifdef __cplusplus
}
#endif

#endif /* __SH32F9XX_SC0_SYSCFG_H */

/**
  * @}
  */ 

/**
  * @}
  */ 

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
