/**
 ******************************************************************************
 * @file    sh32f9xx_sc0_amoc.c
 * @author  sinowealth
 * @version V1.1.0
 * @date    2021-11-11
 * @brief   This file provides firmware functions to manage the following
 *
 *  @verbatim
 *
 *          ===================================================================
 *                                   How to use this driver
 *          ===================================================================
 *
 *  @endverbatim
 *
 ******************************************************************************
 * @attention
 *
 * SINOWEALTH IS SUPPLYING THIS SOFTWARE FOR USE EXCLUSIVELY SH_ON SINOWEALTH'S
 * MICROCONTROLLER PRODUCTS. IT IS PROTECTED UNDER APPLICABLE COPYRIGHT LAWS.
 * THIS SOFTWARE IS FOR GUIDANCE IN ORDER TO SAVE AMOCE. AS A RESULT, SINOWEALTH
 * SHALL NOT BE HELD LIABLE FOR ANY DIRECT, INDIRECT OR CONSEQUENTIAL DAMAGES
 * WITH RESPECT TO ANY CLAIMS ARISING FROM THE CONTENT OF SUCH FIRMWARE AND/OR
 * THE USE MADE BY CUSTOMERS OF THE CODING INFORMATION CONTAINED HEREIN IN
 * CONNECTION WITH THEIR PRODUCTS.
 *
 * <h2><center>&copy; COPYRIGHT 2020 Sinowealth</center></h2>
 *
 ******************************************************************************
 */

/* Includes ------------------------------------------------------------------*/
#include "sh32f9xx_sc0_amoc.h"

/** @addtogroup SH32F9xx_sc0_lib_StdLib_Driver
 * @{
 */

/** @defgroup AMOC_MODULE AMOC
 * @brief AMOC driver modules
 * @{
 */

/* Private typedef -----------------------------------------------------------*/
/* Private define ------------------------------------------------------------*/
/* Private macro -------------------------------------------------------------*/
/* Private variables ---------------------------------------------------------*/
/* Private function prototypes -----------------------------------------------*/
/* Private functions ---------------------------------------------------------*/

/** @defgroup AMOC_Private_Functions
 * @{
 */

/** @defgroup PPP_Group1 Initialization and Configuration
 *  @brief    Initialization and Configuration
 *
@verbatim
 ===============================================================================
                      Initialization and Configuration
 ===============================================================================

@endverbatim
  * @{
  */

/**
 * @brief  Fills each AMOC_InitStruct member with its default value.
 * @param  AMOC_InitStruct : pointer to a @ref AMOC_InitTypeDef
 *         structure which will be initialized.
 * @retval None
 */
void AMOC_StructInit(AMOC_CMP_Init_TypeDef *AMOC_InitStruct)
{
    AMOC_InitStruct->AMOC_CMPX_CTR = AMOC_CMP0_CTR;
    AMOC_InitStruct->AMOC_CMP_Vcmp = AVDD_REF;
    AMOC_InitStruct->AMOC_CMP_VOL_SEL = INVER_REFVOL_8;
    AMOC_InitStruct->AMOC_CMP_DMAEN   = SH_DISABLE;
    AMOC_InitStruct->AMOC_CMP_INT_MODSEL = INT_MODE_NO;
    AMOC_InitStruct->AMOC_CMP_OUTEN = SH_DISABLE;
    AMOC_InitStruct->AMOC_CMP_SMIT_VOLSEL  = SMIT_VOL_NO;
    AMOC_InitStruct->AMOC_CMP_CMPONOROFF   = SH_OFF;
    AMOC_InitStruct->AMOC_CMP_INVERT_INSEL = CMP_VRS;
    AMOC_InitStruct->AMOC_CMP_OUT_FILTETIM = FILT_TIMR_NO;
}

/**
 * @brief  Initializes the AMOCx peripheral according to the specified parameters
 *         in the AMOC_InitStruct.
 * @param  AMOCx: where be the AMOC peripheral.
 * @param  AMOC_InitStruct: pointer to a @ref AMOC_InitTypeDef structure that contains
 *         the configuration information for the specified AMOC peripheral.
 * @retval None
 */
void AMOC_CTR_Init(AMOC_TypeDef *AMOCx, AMOC_CMP_Init_TypeDef *AMOC_InitStruct)
{
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_InitStruct->AMOC_CMPX_CTR));
    assert_param(IS_CMP_VCMP_TypeDef(AMOC_InitStruct->AMOC_CMP_Vcmp));
    assert_param(IS_CMP_REFVOL_SEL_TypeDef(AMOC_InitStruct->AMOC_CMP_VOL_SEL));
    assert_param(IS_FUNCTION_STATE(AMOC_InitStruct->AMOC_CMP_DMAEN));
    assert_param(IS_CMP_INTMOD_SEL_TypeDef(AMOC_InitStruct->AMOC_CMP_INT_MODSEL));
    assert_param(IS_FUNCTION_STATE(AMOC_InitStruct->AMOC_CMP_OUTEN));
    assert_param(IS_CMP_SMIT_VOLSEL_TypeDef(AMOC_InitStruct->AMOC_CMP_SMIT_VOLSEL));
    assert_param(IS_CMD_STATE(AMOC_InitStruct->AMOC_CMP_CMPONOROFF));
    assert_param(IS_CMP_INVERT_INSEL_TypeDef(AMOC_InitStruct->AMOC_CMP_INVERT_INSEL));
    assert_param(IS_CMP_FILT_TIMR_TypeDef(AMOC_InitStruct->AMOC_CMP_OUT_FILTETIM));

    if (AMOC_InitStruct->AMOC_CMPX_CTR == AMOC_CMP0_CTR)
    {
        AMOCx->CMP0CON.V32 = ((AMOC_InitStruct->AMOC_CMP_Vcmp) << AMOC_CMP0CON_CMP0VCMP_Pos) | ((AMOC_InitStruct->AMOC_CMP_VOL_SEL) << AMOC_CMP0CON_CMP0VRS_Pos) | ((AMOC_InitStruct->AMOC_CMP_DMAEN) << AMOC_CMP0CON_C0DE_Pos) | ((AMOC_InitStruct->AMOC_CMP_INT_MODSEL) << AMOC_CMP0CON_C0IES_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUTEN) << AMOC_CMP0CON_C0OUTEN_Pos) | ((AMOC_InitStruct->AMOC_CMP_SMIT_VOLSEL) << AMOC_CMP0CON_C0SMT_Pos) | ((AMOC_InitStruct->AMOC_CMP_CMPONOROFF) << AMOC_CMP0CON_CMP0EN_Pos) | ((AMOC_InitStruct->AMOC_CMP_INVERT_INSEL) << AMOC_CMP0CON_C0NCHS_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUT_FILTETIM) << AMOC_CMP0CON_C0DEB_Pos);
    }
    else if (AMOC_InitStruct->AMOC_CMPX_CTR == AMOC_CMP1_CTR)
    {
        AMOCx->CMP1CON.V32 = ((AMOC_InitStruct->AMOC_CMP_Vcmp) << AMOC_CMP1CON_CMP1VCMP_Pos) | ((AMOC_InitStruct->AMOC_CMP_VOL_SEL) << AMOC_CMP1CON_CMP1VRS_Pos) | ((AMOC_InitStruct->AMOC_CMP_DMAEN) << AMOC_CMP1CON_C1DE_Pos) | ((AMOC_InitStruct->AMOC_CMP_INT_MODSEL) << AMOC_CMP1CON_C1IES_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUTEN) << AMOC_CMP1CON_C1OUTEN_Pos) | ((AMOC_InitStruct->AMOC_CMP_SMIT_VOLSEL) << AMOC_CMP1CON_C1SMT_Pos) | ((AMOC_InitStruct->AMOC_CMP_CMPONOROFF) << AMOC_CMP1CON_CMP1EN_Pos) | ((AMOC_InitStruct->AMOC_CMP_INVERT_INSEL) << AMOC_CMP1CON_C1NCHS_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUT_FILTETIM) << AMOC_CMP1CON_C1DEB_Pos);
    }
    else if (AMOC_InitStruct->AMOC_CMPX_CTR == AMOC_CMP0_CTR)
    {
        AMOCx->CMP0CON.V32 = ((AMOC_InitStruct->AMOC_CMP_Vcmp) << AMOC_CMP2CON_CMP2VCMP_Pos) | ((AMOC_InitStruct->AMOC_CMP_VOL_SEL) << AMOC_CMP2CON_CMP2VRS_Pos) | ((AMOC_InitStruct->AMOC_CMP_DMAEN) << AMOC_CMP2CON_C2DE_Pos) | ((AMOC_InitStruct->AMOC_CMP_INT_MODSEL) << AMOC_CMP2CON_C2IES_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUTEN) << AMOC_CMP2CON_C2OUTEN_Pos) | ((AMOC_InitStruct->AMOC_CMP_SMIT_VOLSEL) << AMOC_CMP2CON_C2SMT_Pos) | ((AMOC_InitStruct->AMOC_CMP_CMPONOROFF) << AMOC_CMP2CON_CMP2EN_Pos) | ((AMOC_InitStruct->AMOC_CMP_INVERT_INSEL) << AMOC_CMP2CON_C2NCHS_Pos) | ((AMOC_InitStruct->AMOC_CMP_OUT_FILTETIM) << AMOC_CMP2CON_C2DEB_Pos);
    }
}

/**
 * @brief  Comparator X I/O output port enable or disable.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @param  AMOC_CMPX_OUTEN : This parameter can be a value of @ref FunctionalState.
 * @retval None
 */
void AMOC_CMP_OUTPUTEN(CMP_CTR_TypeDef AMOC_CMPAX_CTR, FunctionalState AMOC_CMPX_OUTEN)
{
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));
    assert_param(IS_FUNCTION_STATE(AMOC_CMPX_OUTEN));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        AMOC->CMP0CON.BIT.C0OUTEN = AMOC_CMPX_OUTEN;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        AMOC->CMP1CON.BIT.C1OUTEN = AMOC_CMPX_OUTEN;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        AMOC->CMP2CON.BIT.C2OUTEN = AMOC_CMPX_OUTEN;
    }
}

/**
 * @brief  Comparator X triggers DMA enable bit.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @param  AMOC_CMPX_DMAEN : This parameter can be a value of @ref FunctionalState.
 * @retval None
 */
void AMOC_CMP_DMAEN(CMP_CTR_TypeDef AMOC_CMPAX_CTR, FunctionalState AMOC_CMPX_DMAEN)
{
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));
    assert_param(IS_FUNCTION_STATE(AMOC_CMPX_DMAEN));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        AMOC->CMP0CON.BIT.C0DE = AMOC_CMPX_DMAEN;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        AMOC->CMP1CON.BIT.C1DE = AMOC_CMPX_DMAEN;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        AMOC->CMP2CON.BIT.C2DE = AMOC_CMPX_DMAEN;
    }
}

/**
 * @brief  Comparator x enable or disable control bit.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @param  AMOC_CMPX_ONOROFF : This parameter can be a value of @ref CmdState.
 * @retval None
 */
void AMOC_CMP_ONOROFF(CMP_CTR_TypeDef AMOC_CMPAX_CTR, CmdState AMOC_CMPX_ONOROFF)
{
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));
    assert_param(IS_CMD_STATE(AMOC_CMPX_ONOROFF));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        AMOC->CMP0CON.BIT.CMP0EN = AMOC_CMPX_ONOROFF;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        AMOC->CMP1CON.BIT.CMP1EN = AMOC_CMPX_ONOROFF;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        AMOC->CMP2CON.BIT.CMP2EN = AMOC_CMPX_ONOROFF;
    }
}

/**
 * @brief  Get Comparator X output level state.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @retval This parameter can be a value of @ref LevelStatus.
 */
LevelStatus AMOC_CMP_OUTGET(CMP_CTR_TypeDef AMOC_CMPAX_CTR)
{
    uint8_t getlevelsta = 0;
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        getlevelsta = AMOC->CMP0CON.BIT.C0OUT;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        getlevelsta = AMOC->CMP1CON.BIT.C1OUT;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        getlevelsta = AMOC->CMP2CON.BIT.C2OUT;
    }
    if (!getlevelsta)
    {
        return SH_LOW;
    }
    else
    {
        return SH_HIGH;
    }
}

/**
 * @brief  Get Comparator x interrupt flag.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @retval This parameter can be a value of @ref FlagStatus.
 */
FlagStatus AMOC_CMP_INTIFGET(CMP_CTR_TypeDef AMOC_CMPAX_CTR)
{
    uint8_t getlevelsta = 0;
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        getlevelsta = AMOC->CMPINTF.BIT.C0IF;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        getlevelsta = AMOC->CMPINTF.BIT.C1IF;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        getlevelsta = AMOC->CMPINTF.BIT.C2IF;
    }
    if (!getlevelsta)
    {
        return SH_RESET;
    }
    else
    {
        return SH_SET;
    }
}

/**
 * @brief  Comparator x interrupt flag clear.
 * @param  AMOC_CMPAX_CTR  : This parameter can be a value of @ref CMP_CTR_TypeDef.
 * @param  AMOC_CMPX_FLGCLR : This parameter can be a value of @ref CMP_INTCLR_TypeDef.
 * @retval None
 */
void AMOC_CMP_FLGCLER(CMP_CTR_TypeDef AMOC_CMPAX_CTR, CMP_INTCLR_TypeDef AMOC_CMPX_FLGCLR)
{
    /* check the parameters */
    assert_param(IS_CMP_CTR_TypeDef(AMOC_CMPAX_CTR));
    assert_param(IS_CMP_INTCLR_TypeDef(AMOC_CMPX_FLGCLR));

    if (AMOC_CMPAX_CTR == AMOC_CMP0_CTR)
    {
        AMOC->CMPINTF.V32 = CMP0_INT_CLR;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP1_CTR)
    {
        AMOC->CMP1CON.V32 = CMP1_INT_CLR;
    }
    else if (AMOC_CMPAX_CTR == AMOC_CMP2_CTR)
    {
        AMOC->CMP2CON.V32 = CMP2_INT_CLR;
    }
}

/**
 * @brief  Comparator 0 non-inverting input terminal selection.
 * @param  AMOC_CMP0_POSINPUT: This parameter can be a value of @ref CMP0_FRWRD_INSEL_TypeDef.
 * @retval None
 */
void AMOC_CMP0_POSINPUTSEL(CMP0_FRWRD_INSEL_TypeDef AMOC_CMP0_POSINPUT)
{
    /* check the parameters */
    assert_param(IS_CMP0_FRWRD_INSEL_TypeDef(AMOC_CMP0_POSINPUT));
    AMOC->CMP0CON.BIT.C0PCHS = AMOC_CMP0_POSINPUT;
}

/**
 * @brief  Comparator 1 non-inverting input terminal selection.
 * @param  AMOC_CMP1_POSINPUT: This parameter can be a value of @ref CMP1_FRWRD_INSEL_TypeDef.
 * @retval None
 */
void AMOC_CMP1_POSINPUTSEL(CMP1_FRWRD_INSEL_TypeDef AMOC_CMP1_POSINPUT)
{
    /* check the parameters */
    assert_param(IS_CMP1_FRWRD_INSEL_TypeDef(AMOC_CMP1_POSINPUT));
    AMOC->CMP1CON.BIT.C1PCHS = AMOC_CMP1_POSINPUT;
}

/**
 * @brief  Comparator 2 non-inverting input terminal selection.
 * @param  AMOC_CMP2_POSINPUT: This parameter can be a value of @ref CMP2_FRWRD_INSEL_TypeDef.
 * @retval None
 */
void AMOC_CMP2_POSINPUTSEL(CMP2_FRWRD_INSEL_TypeDef AMOC_CMP2_POSINPUT)
{
    /* check the parameters */
    assert_param(IS_CMP2_FRWRD_INSEL_TypeDef(AMOC_CMP2_POSINPUT));
    AMOC->CMP2CON.BIT.C2PCHS = AMOC_CMP2_POSINPUT;
}

/**
 * @brief  Operational amplifier X disable or enable control bit.
 * @param  AMOC_AMPLX  : This parameter can be a value of @ref CMP_AMPL_TypeDef.
 * @param  AMOC_AMPLX_DISOREN : This parameter can be a value of @ref FunctionalState.
 * @retval None
 */
void AMOC_AMPL_DISOREN(CMP_AMPL_TypeDef AMOC_AMPLX, FunctionalState AMOC_AMPLX_DISOREN)
{
    /* check the parameters */
    assert_param(IS_CMP_AMPLX_TypeDef(AMOC_AMPLX));
    assert_param(IS_FUNCTION_STATE(AMOC_AMPLX_DISOREN));

    if (AMOC_AMPLX == AMOC_AMPL0)
    {
        AMOC->OPCON.BIT.OP0EN = AMOC_AMPLX_DISOREN;
    }
    else if (AMOC_AMPLX == AMOC_AMPL1)
    {
        AMOC->OPCON.BIT.OP1EN = AMOC_AMPLX_DISOREN;
    }
    else
    {
        AMOC->OPCON.BIT.OP2EN = AMOC_AMPLX_DISOREN;
    }
}

/**
 * @brief  Built-in voltage output selection bit.
 * @param  AMOC_CMPX_DMAEN : This parameter can be a value of @ref FunctionalState.
 * @retval None
 */
void AMOC_VREF_BUILTIN(CMP_BUILDIN_VREFVOL_TypeDef AMOC_VREF_BUIN)
{
    /* check the parameters */
    assert_param(IS_CMP_BUILDIN_VREFVOL_TypeDef(AMOC_VREF_BUIN));

    AMOC->AVREFCON.V32 = AMOC_VREF_BUIN;
}

/**
 * @brief  Built-in voltage weather turn on bit.
 * @param  AMOC_VOLBUIN_ONOROFF : This parameter can be a value of @ref CmdState.
 * @retval None
 */
void AMOC_VOLIN_ONOROFF(CmdState AMOC_VOLBUIN_ONOROFF)
{
    /* check the parameters */
    assert_param(IS_CMD_STATE(AMOC_VOLBUIN_ONOROFF));

    AMOC->AVREFCON.BIT.VREFEN = AMOC_VOLBUIN_ONOROFF;
}

/**
 * @}
 */

/************************ (C) COPYRIGHT Sinowealth *****END OF FILE****/
